BuiltArtifactHeaderData

Struct BuiltArtifactHeaderData 

pub struct BuiltArtifactHeaderData {
    pub dependencies: Vec<ArtifactId>,
    pub asset_type: Uuid,
}
Data encoded into the artifact. This is necessary for loading but is not available in memory at all times. The load process will fetch this from the top of the built artifact data. This is specifically designed to read the minimum amount of info out of the file.

Fields

dependencies: Vec<ArtifactId>asset_type: Uuid

Implementations