DebugManifestFileJson

Struct DebugManifestFileJson 

pub struct DebugManifestFileJson {
    pub artifacts: Vec<DebugArtifactManifestDataJson>,
}
Used to store debug manifest data. It’s not needed for the game to function but can be used in addition to the release manifest to get helpful debug info

Fields

artifacts: Vec<DebugArtifactManifestDataJson>