pub enum HandleRefType {
Strong(Sender<RefOp>),
Weak(Sender<RefOp>),
Internal(Sender<RefOp>),
None,
}Expand description
Keeps track of whether a handle ref is a strong, weak or “internal” ref
Variants
Strong(Sender<RefOp>)
Strong references decrement the count on drop
Weak(Sender<RefOp>)
Weak references do nothing on drop.
Internal(Sender<RefOp>)
Internal references do nothing on drop, but turn into Strong references on clone. Should only be used for references stored in loaded artifacts to avoid self-referencing
None
Implementation detail, used when changing state in this enum