pub struct DummySerdeContext { /* private fields */ }Expand description
This context can be used to maintain ArtifactId references through a serialize/deserialize cycle even if the LoadHandles produced are invalid. This is useful when a loader is not present, such as when processing in the Distill Daemon.
Implementations