WeakHandle

Struct WeakHandle 

pub struct WeakHandle { /* private fields */ }
Handle to an artifact that does not prevent the artifact from being unloaded.

Weak handles are primarily used when you want to use something that is already loaded.

For example, a strong handle to an artifact may be guaranteed to exist elsewhere in the program, and so you can simply get and use a weak handle to that artifact in other parts of your code. This removes reference counting overhead, but also ensures that the system which uses the weak handle is not in control of when to unload the artifact.

Implementations

Source

impl WeakHandle

pub fn new(handle: Arc<ResolvedLoadHandle>) -> Self