Module uuid_path

Module uuid_path 

Functions

path_to_uuid
Converts a path within a root to a UUID
path_to_uuid_and_hash
Converts a path within a root to a UUID + u64 hash
uuid_and_hash_to_path
Converts a UUID to a path starting at the given root and with the given extension and appends a u64 hash of the contents Example: /2/d/2d41f453d6224b2fab9bc8021a6c7dde-45647afbadf0c93d.bf
uuid_to_path
Converts a UUID to a path starting at the given root and with the given extension Example: /2/d/2d4154f72b3c422387677e8d1fa70447.af