pub struct DebugManifestFileJson {
pub artifacts: Vec<DebugArtifactManifestDataJson>,
}Expand description
Used to store debug manifest data. It’s not needed for the game to function but can be used in addition to the release manifest to get helpful debug info
Fields
artifacts: Vec<DebugArtifactManifestDataJson>Trait Implementations
Sourceimpl Default for DebugManifestFileJson
impl Default for DebugManifestFileJson
Sourcefn default() -> DebugManifestFileJson
fn default() -> DebugManifestFileJson
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for DebugManifestFileJson
impl<'de> Deserialize<'de> for DebugManifestFileJson
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more