Module uuid_path
hydrate_
base
0.0.2
Module uuid_
path
Module Items
Functions
In crate hydrate_
base
hydrate_base
Module
uuid_
path
Functions

path_
to_
uuid
Converts a path within a root to a UUID
path_
to_
uuid_
and_
hash
Converts a path within a root to a UUID + u64 hash
uuid_
and_
hash_
to_
path
Converts a UUID to a path starting at the given root and with the given extension and appends a u64 hash of the contents Example: /2/d/2d41f453d6224b2fab9bc8021a6c7dde-45647afbadf0c93d.bf
uuid_
to_
path
Converts a UUID to a path starting at the given root and with the given extension Example: /2/d/2d4154f72b3c422387677e8d1fa70447.af